@@ -2,13 +2,10 @@
 import sys
 import os
 
-from os.path import abspath, dirname, join
-
-from django.conf import settings
-from django.core.management import setup_environ, execute_from_command_line
+from django.core.management import execute_from_command_line
 
 try:
-    import settings as settings_mod # Assumed to be in the same directory.
+    import settings as settings_mod  # Assumed to be in the same directory.
 except ImportError:
     sys.stderr.write("Error: Can't find the file 'settings.py' in the directory containing %r. It appears you've customized things.\nYou'll have to run django-admin.py, passing it your settings module.\n(If the file settings.py does indeed exist, it's causing an ImportError somehow.)\n" % __file__)
     sys.exit(1)
@@ -16,8 +13,7 @@ except ImportError:
 sys.path.insert(0, settings_mod.PROJECT_ROOT)
 sys.path.insert(0, settings_mod.PROJECT_ROOT + '/../')
 
-# setup the environment before we start accessing things in the settings.
-setup_environ(settings_mod)
+os.environ.setdefault("DJANGO_SETTINGS_MODULE", 'example.settings')
 
 if __name__ == "__main__":
-    execute_from_command_line()
+    execute_from_command_line(sys.argv)
