@@ -1,5 +1,7 @@
-
-from django.conf.urls.defaults import patterns, include, handler500, url
+try:
+    from django.conf.urls import patterns, include, handler500, url
+except ImportError:  # django < 1.4
+    from django.conf.urls.defaults import patterns, include, handler500, url
 from django.conf import settings
 from django.contrib import admin
 import authority
